[TODO: write documentation for this plugin.] { "name": "ASGIWebPythonPlugin", "type": "web-python", "version": "0.1.0", "description": "[TODO: describe this plugin with one sentence.]", "tags": [], "ui": "", "cover": "", "inputs": null, "outputs": null, "flags": [], "icon": "extension", "api_version": "0.1.7", "env": "", "permissions": [], "requirements": ["fastapi==0.70.0"], "dependencies": [], "services": ["hello-fastapi"] }